# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
###  [2.0.0]
### Added
- Added vim text-editor to support post build modification or testing.
- Added script to create an ingest file with random names and data for
  testing large datasets.

### Changed
- Update update.py ingest algorithms

### Fixed
- TBA

### Security
- TBA
## [1.0.0] - 2020-04-22

Initial release
## [1.0.1] - 2020-07-27
### Fixed
- MSISet interpolate method returning empty list.

## [1.0.2] - 2020-07-28
### Fixed
- Fixed: Issue with syncing home dirs during re-deployment.




